@@ -25,12 +25,10 @@ import logging
 import subprocess
 import tempfile
 import sys
-import threading
 
 from aptsources.sourceslist import SourceEntry
 
 from dbus.mainloop.glib import DBusGMainLoop
-from softwareproperties.LivepatchService import LivepatchService
 from softwareproperties.SoftwareProperties import SoftwareProperties
 
 DBUS_BUS_NAME = 'com.ubuntu.SoftwareProperties'
@@ -52,7 +50,8 @@ class SoftwarePropertiesDBus(dbus.service.Object, SoftwareProperties):
 
     def __init__(self, bus, options=None, datadir=None, rootdir="/"):
         # init software properties
-        SoftwareProperties.__init__(self, options=options, datadir=datadir, rootdir=rootdir)
+        SoftwareProperties.__init__(self, options=options, datadir=datadir,
+                                    rootdir=rootdir, deb822=True)
         # used in _check_policykit_priviledge
         self.dbus_info = None
         self.polkit = None
@@ -63,8 +62,6 @@ class SoftwarePropertiesDBus(dbus.service.Object, SoftwareProperties):
         self.enforce_polkit = True
         logging.debug("waiting for connections")
 
-        self._livepatch_service = LivepatchService()
-
     # override set_modified_sourceslist to emit a signal
     def save_sourceslist(self):
         super(SoftwarePropertiesDBus, self).save_sourceslist()
@@ -201,7 +198,7 @@ class SoftwarePropertiesDBus(dbus.service.Object, SoftwareProperties):
 
     def _add_cdrom_source(self):
         """ add a (already inserted) cdrom """
-        tmp = tempfile.NamedTemporaryFile()    
+        tmp = tempfile.NamedTemporaryFile()
         # need to call it here because python-apt does not support
         # AutoDetect mode yet
         cmd = ["apt-cdrom", "add",
@@ -225,7 +222,7 @@ class SoftwarePropertiesDBus(dbus.service.Object, SoftwareProperties):
         if res != 0:
             self.CdromScanFailed()
             return False
-        # read tmp file with source name 
+        # read tmp file with source name
         line = ""
         # (read only last line)
         for x in open(tmp.name):
@@ -266,7 +263,7 @@ class SoftwarePropertiesDBus(dbus.service.Object, SoftwareProperties):
     def SetUpdateInterval(self, days, sender=None, conn=None):
         self._check_policykit_privilege(
             sender, conn, "com.ubuntu.softwareproperties.applychanges")
-        self.set_update_interval(days)
+        self.set_update_interval(int(days))
 
     # Sources
 
@@ -295,7 +292,10 @@ class SoftwarePropertiesDBus(dbus.service.Object, SoftwareProperties):
     def AddKey(self, path, sender=None, conn=None):
         self._check_policykit_privilege(
             sender, conn, "com.ubuntu.softwareproperties.applychanges")
-        return self.add_key(path)
+        res = self.add_key(path)
+        if res:
+            self.KeysModified()
+        return res
 
     @dbus.service.method(DBUS_INTERFACE_NAME,
                          sender_keyword="sender", connection_keyword="conn",
@@ -303,7 +303,10 @@ class SoftwarePropertiesDBus(dbus.service.Object, SoftwareProperties):
     def AddKeyFromData(self, keyData, sender=None, conn=None):
         self._check_policykit_privilege(
             sender, conn, "com.ubuntu.softwareproperties.applychanges")
-        return self.add_key_from_data(keyData)
+        res = self.add_key_from_data(keyData)
+        if res:
+            self.KeysModified()
+        return res
 
     @dbus.service.method(DBUS_INTERFACE_NAME,
                          sender_keyword="sender", connection_keyword="conn",
@@ -311,28 +314,10 @@ class SoftwarePropertiesDBus(dbus.service.Object, SoftwareProperties):
     def RemoveKey(self, keyid, sender=None, conn=None):
         self._check_policykit_privilege(
             sender, conn, "com.ubuntu.softwareproperties.applychanges")
-        return self.remove_key(keyid)
-
-    @dbus.service.method(DBUS_INTERFACE_NAME,
-                         sender_keyword="sender", connection_keyword="conn",
-                         in_signature='', out_signature='b')
-    def UpdateKeys(self, sender=None, conn=None):
-        self._check_policykit_privilege(
-            sender, conn, "com.ubuntu.softwareproperties.applychanges")
-        return self.update_keys()
-
-    # LivePatch
-    @dbus.service.method(DBUS_INTERFACE_NAME,
-                         sender_keyword="sender", connection_keyword="conn",
-                         in_signature='bs', out_signature='bs', async_callbacks=('reply_handler', 'error_handler'))
-    def SetLivepatchEnabled(self, enabled, token, reply_handler, error_handler, sender=None, conn=None):
-        def enable_thread_func():
-            ret = self._livepatch_service.set_enabled(enabled, token)
-            GLib.idle_add(lambda: reply_handler(*ret))
-
-        self._check_policykit_privilege(
-            sender, conn, "com.ubuntu.softwareproperties.applychanges")
-        threading.Thread(target=enable_thread_func).start()
+        res = self.remove_key(keyid)
+        if res:
+            self.KeysModified()
+        return res
 
     # helper from jockey
     def _check_policykit_privilege(self, sender, conn, privilege):
