@@ -428,7 +428,7 @@ class SoftwarePropertiesGtk(SoftwareProperties, SimpleGtkbuilderApp):
         """Setup the user interface elements to represent the distro"""
 
         # TRANS: %s stands for the distribution name e.g. Debian or Ubuntu
-        self.label_dist_name.set_label(_("%s Software") % self.distro.id)
+        self.label_dist_name.set_label(_("%s Software") % self.distro.id.capitalize())
 
         self.handlers[self.checkbutton_source_code] = \
                               self.checkbutton_source_code.connect("toggled",
