@@ -1,7 +1,5 @@
 #!/usr/bin/python3
 
-from __future__ import print_function
-
 import aptsources.distro
 import aptsources.sourceslist
 import unittest
@@ -67,7 +65,7 @@ class TestAptSources(unittest.TestCase):
                 "multiverse" in entry.comps):
                 found = True
         self.assertTrue(found)
-        # test to add something new: multiverse *and* 
+        # test to add something new: multiverse *and*
         # something that is already there
         before = copy.deepcopy(sources)
         sources.add("deb","http://de.archive.ubuntu.com/ubuntu/",
@@ -89,6 +87,8 @@ class TestAptSources(unittest.TestCase):
         self.assertEqual(found_universe, 1)
 
     def testDistribution(self):
+        # Pretend to be amd64, so we don't get tripped up by ubuntu-ports architectures
+        apt_pkg.config.set("APT::Architecture", "amd64")
         apt_pkg.config.set("Dir::Etc::sourcelist",
                            self.sources_list+".testDistribution")
         sources = aptsources.sourceslist.SourcesList()
@@ -102,7 +102,7 @@ class TestAptSources(unittest.TestCase):
         #print(dist_templates)
         for d in ["edgy","edgy-security","edgy-updates","hoary"]:
             self.assertTrue(d in dist_templates)
-        # test enable 
+        # test enable
         comp = "restricted"
         distro.enable_component(comp)
         found = {}
