@@ -314,9 +314,9 @@ class TestDBus(unittest.TestCase):
     def test_add_gpg_key(self):
         # clean
         gpg_glob = os.path.join(os.path.dirname(__file__),
-                              "aptroot", "etc", "apt", "*.gpg")
-        trusted_gpg = os.path.join(os.path.dirname(__file__),
-                                   "aptroot", "etc", "apt", "trusted.gpg")
+                              "aptroot", "etc", "apt", "trusted.gpg.d", "*.asc")
+        trusted_gpg_d = os.path.join(os.path.dirname(__file__),
+                                     "aptroot", "etc", "apt", "trusted.gpg.d/")
         testkey = os.path.join(os.path.dirname(__file__),
                                "data", "testkey.asc")
         for f in glob.glob(gpg_glob):
@@ -327,24 +327,21 @@ class TestDBus(unittest.TestCase):
                                              "data", "testkey.asc"))
         self.assertTrue(res)
         self.assertEqual(len(glob.glob(gpg_glob)), 1)
-        self.assertNotEqual(os.path.getsize(trusted_gpg), 0)
+        self.assertNotEqual(os.path.getsize(trusted_gpg_d + "testkey.asc"), 0)
         # remove the key
-        res = self.iface.RemoveKey("D732CA59")
+        res = self.iface.RemoveKey(trusted_gpg_d + "testkey.asc")
         self.assertTrue(res)
-        if os.path.exists(trusted_gpg):
-            self.assertEqual(os.path.getsize(trusted_gpg), 0)
+        self.assertEqual(len(glob.glob(gpg_glob)), 0)
         # add from data
         with open(testkey) as keyfile:
             data = keyfile.read()
             res = self.iface.AddKeyFromData(data)
             self.assertTrue(res)
-            self.assertEqual(len(glob.glob(gpg_glob)), 1)
-            self.assertNotEqual(os.path.getsize(trusted_gpg), 0)
+            self.assertEqual(len(os.listdir(trusted_gpg_d)), 1)
         # remove the key
-        res = self.iface.RemoveKey("D732CA59")
+        res = self.iface.RemoveKey(trusted_gpg_d + "/46caf96d27ee1eebcf139483275a5c1bb41590474e35f8bb4ae3cceb413f7518.gpg")
         self.assertTrue(res)
-        if os.path.exists(trusted_gpg):
-            self.assertEqual(os.path.getsize(trusted_gpg), 0)
+        self.assertEqual(len(os.listdir(trusted_gpg_d)), 1)
         # test nonsense
         res = self.iface.AddKeyFromData("nonsens")
         self.assertFalse(res)
