@@ -3,18 +3,17 @@ import os
 import subprocess
 import unittest
 
-@unittest.skip("It's not clean")
 class TestPyflakesClean(unittest.TestCase):
     """ ensure that the tree is pyflakes clean """
 
-    BLACKLIST = ("/softwareproperties/qt",
+    BLOCKLIST = ("/softwareproperties/qt",
                 )
 
     def setUp(self):
         self.paths = []
         basedir = os.path.abspath(os.path.join(os.path.dirname(__file__), ".."))
         for dirpath, dirs, files in os.walk(basedir):
-            if any([dirpath.endswith(p) for p in self.BLACKLIST]):
+            if any([dirpath.endswith(p) for p in self.BLOCKLIST]):
                 continue
             self.paths.extend(glob.glob(dirpath+"/*.py"))
 
